import { ComponentConstructorInfo, ComponentDrawInfo } from '../types';
import Component from '../common/Component';
import { SN } from '../common/definitions';
import AxisBody from '../Axis/AxisBody';
import EventMark from './EventMark';
/**
 * @property {Readonly<Axis['drawInfo']>} axisBodyDrawInfo - the DrawInfo of AxisBody.
 * @property {Readonly<EventMark['drawInfo']>} markDrawInfo - the DrawInfo of EventMark.
 * @property {number} length - the length of EventAxis.
 * @property {number} offsetX - the offset X with Axis in EventAxis.
 * @property {[string]} text - the description about event ended.
 * */
interface DrawInfo extends ComponentDrawInfo {
    axisBodyDrawInfo: Readonly<AxisBody['drawInfo']>;
    markDrawInfo: Readonly<EventMark['drawInfo']>;
    length: number;
    offsetX: number;
    text?: string;
}
/**
 * Recognize a event time of duration and end time point.
 * Some Event have no duration, so it needn't EventAxis.
 * Can conflict with AxisMilestone and EventAxis.
 * */
export default abstract class EventAxis extends Component {
    constructor(props: ComponentConstructorInfo);
    name: SN;
    drawInfo: DrawInfo;
    createElement(): import("../common/Component").MUST_CALL_AND_RETURN_SUPER_METHOD;
    createBox(): void;
    apply(): Promise<import("../common/Component").MUST_CALL_AND_RETURN_SUPER_METHOD>;
    draw(): import("../common/Component").MUST_CALL_AND_RETURN_SUPER_METHOD;
    static is(comp: Component): comp is EventAxis;
}
export {};
