import { ComponentDrawInfo, Coordinate, ComponentConstructorInfo } from '../types';
import Component from '../common/Component';
import { SN } from '../common/definitions';
import EventMark from './EventMark';
/**
 * @property {Readonly<EventMark['drawInfo']>} markDrawInfo - the DrawInfo of EventMark.
 * @property {Coordinate} offset - configure a coordinate that offset with Axis.
 * @property {number} maxWidth - the EventBody can be stretched max width.
 * @property {Date} date - the data of event.
 * @property {string} title - the title of event.
 * @property {[string]} description - the description of event.
 * @property {boolean} floated - indicate the EventBody was floated or not.
 * @property {boolean} folded - indicate the EventBody was in fold-mode or not.
 * @property {[string]} foldPlaceholder - a text to show when the EventBody was in fold-mode.
 * @property {[Date]} endDate - the date of event end.
 * @property {[string]} endText - the description about event ended.
 * */
interface DrawInfo extends ComponentDrawInfo {
    markDrawInfo: EventMark['drawInfo'];
    offset: Coordinate;
    maxWidth: number;
    date: string;
    title: string;
    description?: string;
    floated: boolean;
    folded: boolean;
    foldPlaceholder?: string;
    endDate?: string;
    endText?: string;
}
/**
 * Can conflict with AxisMilestone and EventBody.
 * */
export default abstract class EventBody extends Component {
    constructor(props: ComponentConstructorInfo);
    name: SN;
    /**
     * An EventBody must has a HTML element for allow user select and copy text from EventBody.
     * @type {HTMLElement}
     * */
    element: HTMLElement;
    drawInfo: DrawInfo;
    createElement(): import("../common/Component").MUST_CALL_AND_RETURN_SUPER_METHOD;
    createBox(): void;
    apply(): Promise<import("../common/Component").MUST_CALL_AND_RETURN_SUPER_METHOD>;
    draw(): import("../common/Component").MUST_CALL_AND_RETURN_SUPER_METHOD;
    applyBoxToElement(): void;
    static is(comp: Component): comp is EventBody;
}
export {};
